==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/SubjectRulesReviewSpecBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class SubjectRulesReviewSpecBuilder extends io.fabric8.openshift.api.model.SubjectRulesReviewSpecFluentImpl<io.fabric8.openshift.api.model.SubjectRulesReviewSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.SubjectRulesReviewSpec,io.fabric8.openshift.api.model.SubjectRulesReviewSpecBuilder>{
  public SubjectRulesReviewSpecBuilder() {
    this(false);
  }
  public SubjectRulesReviewSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new SubjectRulesReviewSpec(), validationEnabled);
  }
  public SubjectRulesReviewSpecBuilder(io.fabric8.openshift.api.model.SubjectRulesReviewSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public SubjectRulesReviewSpecBuilder(io.fabric8.openshift.api.model.SubjectRulesReviewSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new SubjectRulesReviewSpec(), validationEnabled);
  }
  public SubjectRulesReviewSpecBuilder(io.fabric8.openshift.api.model.SubjectRulesReviewSpecFluent<?> fluent,io.fabric8.openshift.api.model.SubjectRulesReviewSpec instance) {
    this(fluent, instance, false);
  }
  public SubjectRulesReviewSpecBuilder(io.fabric8.openshift.api.model.SubjectRulesReviewSpecFluent<?> fluent,io.fabric8.openshift.api.model.SubjectRulesReviewSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withGroups(instance.getGroups()); 
    fluent.withScopes(instance.getScopes()); 
    fluent.withUser(instance.getUser()); 
    this.validationEnabled = validationEnabled; 
  }
  public SubjectRulesReviewSpecBuilder(io.fabric8.openshift.api.model.SubjectRulesReviewSpec instance) {
    this(instance,false);
  }
  public SubjectRulesReviewSpecBuilder(io.fabric8.openshift.api.model.SubjectRulesReviewSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withGroups(instance.getGroups()); 
    this.withScopes(instance.getScopes()); 
    this.withUser(instance.getUser()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.SubjectRulesReviewSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.SubjectRulesReviewSpec build() {
    SubjectRulesReviewSpec buildable = new SubjectRulesReviewSpec(fluent.getGroups(),fluent.getScopes(),fluent.getUser());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SubjectRulesReviewSpecBuilder that = (SubjectRulesReviewSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.12.2-sources.jar: io/fabric8/openshift/api/model/SubjectRulesReviewSpecBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class SubjectRulesReviewSpecBuilder extends io.fabric8.openshift.api.model.SubjectRulesReviewSpecFluentImpl<io.fabric8.openshift.api.model.SubjectRulesReviewSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.SubjectRulesReviewSpec,io.fabric8.openshift.api.model.SubjectRulesReviewSpecBuilder>{
  public SubjectRulesReviewSpecBuilder() {
    this(false);
  }
  public SubjectRulesReviewSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new SubjectRulesReviewSpec(), validationEnabled);
  }
  public SubjectRulesReviewSpecBuilder(io.fabric8.openshift.api.model.SubjectRulesReviewSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public SubjectRulesReviewSpecBuilder(io.fabric8.openshift.api.model.SubjectRulesReviewSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new SubjectRulesReviewSpec(), validationEnabled);
  }
  public SubjectRulesReviewSpecBuilder(io.fabric8.openshift.api.model.SubjectRulesReviewSpecFluent<?> fluent,io.fabric8.openshift.api.model.SubjectRulesReviewSpec instance) {
    this(fluent, instance, false);
  }
  public SubjectRulesReviewSpecBuilder(io.fabric8.openshift.api.model.SubjectRulesReviewSpecFluent<?> fluent,io.fabric8.openshift.api.model.SubjectRulesReviewSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withGroups(instance.getGroups()); 
    fluent.withScopes(instance.getScopes()); 
    fluent.withUser(instance.getUser()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public SubjectRulesReviewSpecBuilder(io.fabric8.openshift.api.model.SubjectRulesReviewSpec instance) {
    this(instance,false);
  }
  public SubjectRulesReviewSpecBuilder(io.fabric8.openshift.api.model.SubjectRulesReviewSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withGroups(instance.getGroups()); 
    this.withScopes(instance.getScopes()); 
    this.withUser(instance.getUser()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.SubjectRulesReviewSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.SubjectRulesReviewSpec build() {
    SubjectRulesReviewSpec buildable = new SubjectRulesReviewSpec(fluent.getGroups(),fluent.getScopes(),fluent.getUser());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SubjectRulesReviewSpecBuilder that = (SubjectRulesReviewSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
